from easy_twitter_interactors.twitter_utils import twitter_utils


def get_proxy():
    return twitter_utils.get_proxy()


def get_headers(cookie: str):
    """获取头"""
    return twitter_utils.get_headers(cookie)



import json
from typing import Dict, Optional, Union

from easy_twitter_interactors.twitter_utils.twitter_utils import request
from .constants import *


class TwitterLikes(object):
    default_headers = {
        'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/107.0.0.0 Safari/537.36',
        'content-type': 'application/json',
    }

    def __init__(self):
        self.requests_kwargs = {}

    def set_headers(self, headers: Optional[Dict[str, str]] = None):
        if headers:
            self.default_headers.update(headers)

    def set_proxy(self, proxy: Optional[Dict[str, str]] = None):
        """
        设置代理
        :param proxy: proxy = {'http': 'http://ip:port', 'https': 'http://ip:port'}
        :return:
        """
        proxies = {
            'proxies': proxy
        }
        self.requests_kwargs.update(proxies)

    def set_timeout(self, timeout: int):
        """
        设置请求超时 单位秒
        """
        self.requests_kwargs['timeout'] = timeout

    def likes(self, to_tweet_id: Union[str, int]):
        """点赞"""
        api = LIKES_API
        payload = json.dumps({
            "variables": {
                "tweet_id": f"{to_tweet_id}"
            },
            # "queryId": "lI07N6Otwv1PhnEgXILM7A"
        })
        response = request('POST', api, headers=self.default_headers, data=payload, **self.requests_kwargs)
        if response.status_code == 200:
            data = response.json()
            return data



""""
推特工具类
"""
from typing import Dict

import requests
import urllib3
from easy_spider_tool import cookie_to_dic
from loguru import logger
from requests import Response, RequestException

urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)

bearer = 'Bearer AAAAAAAAAAAAAAAAAAAAANRILgAAAAAAnNwIzUejRCOuH5E6I8xnZz4puTs%3D1Zv7ttfk8LF81IUq16cHjhLTvJu4FA33AGWWjCpTnA'


def get_proxy():
    """
    获取代理
    """
    proxy_meta = {
        'http': 'http://127.0.0.1:10808',
        'https': 'http://127.0.0.1:10808'
    }
    return proxy_meta


def get_headers(cookie: str):
    assert cookie, '必须设置正确的cookie'
    headers = {
        'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/112.0.0.0 Safari/537.36 Edg/112.0.1722.68',
        'content-type': 'application/json',
        'x-twitter-active-user': 'yes',
        # 'x-twitter-auth-type': 'OAuth2Session',
        'authorization': bearer,
        'x-csrf-token': cookie_to_dic(cookie)['ct0'],
        'cookie': cookie,
    }

    return headers


class MaxRequestRetryCount(Exception):
    pass


def request(method: str, url: str, headers: Dict[str, str] = None, retry_num: int = 3, **kwargs) -> Response:
    retry_count = 0
    while retry_num >= retry_count:
        try:
            return requests.request(method.lower(), url, headers=headers, verify=False, **kwargs)

        except RequestException as rex:
            logger.error(
                f'request exception: {rex}' + f', kwargs: {kwargs}, next retry ...' if retry_count < retry_num else 'exit retry')
            retry_count += 1

    raise MaxRequestRetryCount(f'retry count: {retry_count}')



"""
自定义异常类
"""


class ProxyException(Exception):
    """
    代理异常
    """
    pass


class CaptchaException(Exception):
    """
    验证异常
    """
    pass


class UserException(Exception):
    """
    用户异常信息
    """

    def __init__(self, user_id, msg: str = ''):
        self.user_id = user_id
        self.msg = msg

    def __str__(self):
        return f'【{self.user_id}】: {self.msg}'



from os import path as os_path

from setuptools import setup, find_packages

from easy_twitter_interactors import __version__

this_directory = os_path.abspath(os_path.dirname(__file__))


# 读取文件内容
def read_file(filename):
    with open(os_path.join(this_directory, filename), encoding='utf-8') as f:
        long_description = f.read()
    return long_description


# 获取依赖
def read_requirements(filename):
    return [line.strip() for line in read_file(filename).splitlines()
            if not line.startswith('#')]


if __name__ == '__main__':
    setup(
        name='easy_twitter_interactors',  # 包名
        python_requires='>=3.6.8',  # python环境
        version=__version__,  # 包的版本
        description="简易、好用的推特(Twitter)点赞，刷阅读量程序",  # 包简介，显示在PyPI上
        long_description=read_file('README.md'),  # 读取的Readme文档内容
        long_description_content_type="text/markdown",  # 指定包文档格式为markdown
        author="hanxinkong",  # 作者相关信息
        author_email='xinkonghan@gmail.com',
        url='https://easy-twitter-interactors.xink.top/',
        packages=find_packages(),
        install_requires=read_requirements('requirements.txt'),  # 指定需要安装的依赖
        license="MIT",
        keywords=['easy', 'twitter', 'interactors', 'reads'],
    )
